@@ -13,14 +13,14 @@ mod tests {
     #[test]
     fn test2() {
         use super::{Field, Side};
-        let field = Field::new(160, 8);
+        let field = Field::new(160, 8, 24.66);
         field.render(Side::IASide).save("c.png").unwrap();
     }
 
     #[test]
     fn test() {
         use super::{Color, Column, Coord, Field, Profession, Row, Side};
-        let mut field = Field::new(80, 4);
+        let mut field = Field::new(80, 4, 12.33);
         field.render(Side::IASide).save("a.png").unwrap();
         field.render(Side::ASide).save("b.png").unwrap();
 
@@ -187,7 +187,7 @@ fn multiply_image(a: &image::RgbImage, b: &image::RgbImage) -> Option<image::Rgb
     }
     let mut c = image::RgbImage::new(width, height);
     for (x, y, pixel) in c.enumerate_pixels_mut() {
-        *pixel = multiply_pixel(*a.get_pixel(x, y), *b.get_pixel(x, y))
+        *pixel = multiply_pixel(*a.get_pixel(x, y), *b.get_pixel(x, y));
     }
     Some(c)
 }
@@ -233,10 +233,7 @@ impl Field {
                     .map(PhysicalNonTam2Piece::as_logical)
                     .collect(),
             },
-            floating: match &self.floating {
-                None => None,
-                Some((c, p)) => Some((*c, p.as_logical())),
-            },
+            floating: self.floating.as_ref().map(|(c, p)| (*c, p.as_logical())),
         }
     }
 }
@@ -307,7 +304,7 @@ fn get_vert_offset_from_coord(coord: Coord, down_side: Side) -> i32 {
 
 impl Default for Field {
     fn default() -> Self {
-        Self::new(80, 4)
+        Self::new(80, 4, 12.33)
     }
 }
 
@@ -853,7 +850,7 @@ impl Field {
     }
 
     #[must_use]
-    pub fn new(piece_dimension: u32, padding: u32) -> Field {
+    pub fn new(piece_dimension: u32, padding: u32, length_scale: f64) -> Field {
         use rand::seq::SliceRandom;
         use wood_grain::{wood, BRIGHT_WOOD};
 
@@ -861,7 +858,7 @@ impl Field {
             (piece_dimension + padding) * 6 + piece_dimension,
             (piece_dimension + padding) * 7 + piece_dimension,
             f64::from(piece_dimension) / 2.,
-            12.33,
+            length_scale,
             &BRIGHT_WOOD,
         )
         .expect("should not panic here, since converting u32 to f64 never results in an infinity");
@@ -888,7 +885,7 @@ impl Field {
 
         let mut i = 0;
 
-        let tam2_image = load_from_80x80(&BTAM, piece_dimension);
+        let tam2_image = load_from_80x80(BTAM, piece_dimension);
 
         let res = multiply_image(&tam2_image, &pieces[i])
             .expect("The dimension of `tam2_image` differs from that of `pieces[i]`");
@@ -907,7 +904,7 @@ impl Field {
             let char_image = load_from_80x80(character, piece_dimension);
 
             let res = multiply_image(&char_image, &pieces[i])
-            .expect("The dimension of `char_image` differs from that of `pieces[i]`");
+                .expect("The dimension of `char_image` differs from that of `pieces[i]`");
             // res.save(format!("rawwood_{}.png", i)).unwrap();
 
             hashmap.insert(
